@@ -59,9 +59,11 @@ async def start_client(address, filter_string):
 
 def start(address, filter_string=None, no_dns=False):
     if filter_string is None:
-        filter_string = f"outbound && !loopback && ip && ip.DstAddr != {resolve_address(address)}"
-    
+        filter_string = (
+            f"(outbound && !loopback && ip.DstAddr != {resolve_address(address)} && ip)"
+        )
+
     if no_dns:
-        filter_string = f"{filter_string} && udp.DstPort != 53"
+        filter_string = f"{filter_string} || (outbound && !loopback && ip.DstAddr != {resolve_address(address)} && udp.DstPort != 53)"
 
     loop.run_until_complete(start_client(address, filter_string))
